@@ -3,7 +3,7 @@
 **
 ** <file/class description>
 **
-** Copyright (C) 2002-2004 Steve Lhomme.  All rights reserved.
+** Copyright (C) 2002-2005 Steve Lhomme.  All rights reserved.
 **
 ** This file is part of libmatroska.
 **
@@ -29,7 +29,7 @@
 
 /*!
 	\file
-	\version \$Id: KaxChapters.cpp 1000 2005-01-03 19:20:45Z mosu $
+	\version \$Id: KaxChapters.cpp 1201 2005-08-30 14:28:27Z robux4 $
 	\author Steve Lhomme     <robux4 @ users.sf.net>
 */
 #include "matroska/KaxChapters.h"
@@ -52,7 +52,7 @@ EbmlSemantic KaxEditionEntry_ContextList[5] =
     EbmlSemantic(true , false, KaxChapterAtom::ClassInfos),
 };
 
-EbmlSemantic KaxChapterAtom_ContextList[10] =
+EbmlSemantic KaxChapterAtom_ContextList[12] =
 {
     EbmlSemantic(false, false, KaxChapterAtom::ClassInfos),
     EbmlSemantic(true,  true,  KaxChapterUID::ClassInfos),
@@ -60,6 +60,8 @@ EbmlSemantic KaxChapterAtom_ContextList[10] =
     EbmlSemantic(false, true,  KaxChapterTimeEnd::ClassInfos),
     EbmlSemantic(true , true,  KaxChapterFlagHidden::ClassInfos),
     EbmlSemantic(true , true,  KaxChapterFlagEnabled::ClassInfos),
+    EbmlSemantic(false, true,  KaxChapterSegmentUID::ClassInfos),
+    EbmlSemantic(false, true,  KaxChapterSegmentEditionUID::ClassInfos),
     EbmlSemantic(false, true,  KaxChapterPhysicalEquiv::ClassInfos),
     EbmlSemantic(false, true,  KaxChapterTrack::ClassInfos),
     EbmlSemantic(false, false, KaxChapterDisplay::ClassInfos),
@@ -105,6 +107,8 @@ const EbmlSemanticContext KaxChapterTimeStart_Context = EbmlSemanticContext(0, N
 const EbmlSemanticContext KaxChapterTimeEnd_Context = EbmlSemanticContext(0, NULL, &KaxChapterAtom_Context, *GetKaxGlobal_Context, &KaxChapterTimeEnd::ClassInfos);
 const EbmlSemanticContext KaxChapterFlagHidden_Context = EbmlSemanticContext(0, NULL, &KaxChapterAtom_Context, *GetKaxGlobal_Context, &KaxChapterFlagHidden::ClassInfos);
 const EbmlSemanticContext KaxChapterFlagEnabled_Context = EbmlSemanticContext(0, NULL, &KaxChapterAtom_Context, *GetKaxGlobal_Context, &KaxChapterFlagEnabled::ClassInfos);
+const EbmlSemanticContext KaxChapterSegmentUID_Context = EbmlSemanticContext(0, NULL, &KaxChapterAtom_Context, *GetKaxGlobal_Context, &KaxChapterSegmentUID::ClassInfos);
+const EbmlSemanticContext KaxChapterSegmentEditionUID_Context = EbmlSemanticContext(0, NULL, &KaxChapterAtom_Context, *GetKaxGlobal_Context, &KaxChapterSegmentEditionUID::ClassInfos);
 const EbmlSemanticContext KaxChapterPhysicalEquiv_Context = EbmlSemanticContext(0, NULL, &KaxChapterAtom_Context, *GetKaxGlobal_Context, &KaxChapterPhysicalEquiv::ClassInfos);
 const EbmlSemanticContext KaxChapterTrackNumber_Context = EbmlSemanticContext(0, NULL, &KaxChapterTrack_Context, *GetKaxGlobal_Context, &KaxChapterTrackNumber::ClassInfos);
 const EbmlSemanticContext KaxChapterString_Context = EbmlSemanticContext(0, NULL, &KaxChapterDisplay_Context, *GetKaxGlobal_Context, &KaxChapterString::ClassInfos);
@@ -129,6 +133,8 @@ EbmlId KaxChapterTimeStart_TheId       (0x91, 1);
 EbmlId KaxChapterTimeEnd_TheId         (0x92, 1);
 EbmlId KaxChapterFlagHidden_TheId      (0x98, 1);
 EbmlId KaxChapterFlagEnabled_TheId     (0x4598, 2);
+EbmlId KaxChapterSegmentUID_TheId      (0x6E67, 2);
+EbmlId KaxChapterSegmentEditionUID_TheId(0x6EBC, 2);
 EbmlId KaxChapterPhysicalEquiv_TheId   (0x63C3, 2);
 EbmlId KaxChapterTrack_TheId           (0x8F, 1);
 EbmlId KaxChapterTrackNumber_TheId     (0x89, 1);
@@ -155,6 +161,8 @@ const EbmlCallbacks KaxChapterTimeStart::ClassInfos(KaxChapterTimeStart::Create,
 const EbmlCallbacks KaxChapterTimeEnd::ClassInfos(KaxChapterTimeEnd::Create, KaxChapterTimeEnd_TheId, "ChapterTimeEnd", KaxChapterTimeEnd_Context);
 const EbmlCallbacks KaxChapterFlagHidden::ClassInfos(KaxChapterFlagHidden::Create, KaxChapterFlagHidden_TheId, "ChapterFlagHidden", KaxChapterFlagHidden_Context);
 const EbmlCallbacks KaxChapterFlagEnabled::ClassInfos(KaxChapterFlagEnabled::Create, KaxChapterFlagEnabled_TheId, "ChapterFlagEnabled", KaxChapterFlagEnabled_Context);
+const EbmlCallbacks KaxChapterSegmentUID::ClassInfos(KaxChapterSegmentUID::Create, KaxChapterSegmentUID_TheId, "ChapterSegmentUID", KaxChapterSegmentUID_Context);
+const EbmlCallbacks KaxChapterSegmentEditionUID::ClassInfos(KaxChapterSegmentEditionUID::Create, KaxChapterSegmentEditionUID_TheId, "ChapterSegmentEditionUID", KaxChapterSegmentEditionUID_Context);
 const EbmlCallbacks KaxChapterPhysicalEquiv::ClassInfos(KaxChapterPhysicalEquiv::Create, KaxChapterPhysicalEquiv_TheId, "ChapterPhysicalEquiv", KaxChapterPhysicalEquiv_Context);
 const EbmlCallbacks KaxChapterTrack::ClassInfos(KaxChapterTrack::Create, KaxChapterTrack_TheId, "ChapterTrack", KaxChapterTrack_Context);
 const EbmlCallbacks KaxChapterTrackNumber::ClassInfos(KaxChapterTrackNumber::Create, KaxChapterTrackNumber_TheId, "ChapterTrackNumber", KaxChapterTrackNumber_Context);
